Package: reda
Title: Recurrent Event Data Analysis
Version: 0.5.6
Authors@R: c(
    person(given = "Wenjie", family = "Wang",
           email = "wang@wwenjie.org",
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-0363-3180")),
    person(given = "Haoda", family = "Fu", role = "aut"),
    person(given = "Sy Han (Steven)", family = "Chiou", role = "ctb"),
    person(given = "Jun", family = "Yan", role = "ctb",
           comment = c(ORCID = "0000-0003-4401-7296"))
    )
Description: Contains implementations of recurrent event data analysis routines
    including (1) survival and recurrent event data simulation from
    stochastic process point of view by the thinning method
    proposed by Lewis and Shedler (1979) <doi:10.1002/nav.3800260304>
    and the inversion method introduced in Cinlar (1975, ISBN:978-0486497976),
    (2) the mean cumulative function (MCF) estimation by the
    Nelson-Aalen estimator of the cumulative hazard rate function,
    (3) two-sample recurrent event responses comparison with the pseudo-score
    tests proposed by Lawless and Nadeau (1995) <doi:10.2307/1269617>,
    (4) gamma frailty model with spline rate function following
    Fu, et al. (2016) <doi:10.1080/10543406.2014.992524>.
Imports: Rcpp, graphics, methods, splines2 (>= 0.4.3), stats
LinkingTo: Rcpp, RcppArmadillo
Suggests: ggplot2, grDevices, knitr, rmarkdown, tinytest,
Depends: R (>= 3.2.3)
License: GPL (>= 3)
LazyData: true
VignetteBuilder: knitr
Collate: 'RcppExports.R' 'class.R' 'Recur.R' 'Survr.R' 'aic.R'
        'baseline.R' 'coef.R' 'data.R' 'mcf-generic.R' 'mcf-formula.R'
        'mcf-rateReg.R' 'mcfDiff.R' 'misc.R' 'plot.R' 'rateReg.R'
        'reda-package.R' 'show.R' 'simEvent.R' 'summary.R' 'zzz.R'
URL: https://wwenjie.org/reda, https://github.com/wenjie2wang/reda
BugReports: https://github.com/wenjie2wang/reda/issues
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: yes
Packaged: 2025-09-02 13:02:51 UTC; wenjie
Author: Wenjie Wang [aut, cre] (ORCID: <https://orcid.org/0000-0003-0363-3180>),
  Haoda Fu [aut],
  Sy Han (Steven) Chiou [ctb],
  Jun Yan [ctb] (ORCID: <https://orcid.org/0000-0003-4401-7296>)
Maintainer: Wenjie Wang <wang@wwenjie.org>
Repository: CRAN
Date/Publication: 2025-09-02 14:00:07 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 18:39:11 UTC; unix
Archs: reda.so.dSYM
