# Generated by roxygen2: do not edit by hand

export("%2%")
export("%to%")
export(Recur)
export(Survr)
export(baseRate)
export(check_Recur)
export(is.Recur)
export(mcf)
export(mcfDiff)
export(mcfDiff.test)
export(parametrize)
export(rateReg)
export(rateReg.control)
export(simEvent)
export(simEventData)
exportClasses(Recur)
exportClasses(Survr)
exportClasses(baseRate.rateReg)
exportClasses(mcf.formula)
exportClasses(mcf.rateReg)
exportClasses(mcfDiff)
exportClasses(mcfDiff.test)
exportClasses(rateReg)
exportClasses(simEvent)
exportClasses(summary.Recur)
exportClasses(summary.rateReg)
exportMethods(AIC)
exportMethods(BIC)
exportMethods(baseRate)
exportMethods(coef)
exportMethods(confint)
exportMethods(mcf)
exportMethods(plot)
exportMethods(show)
exportMethods(summary)
importFrom(Rcpp,sourceCpp)
importFrom(graphics,plot)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,setClass)
importFrom(methods,setGeneric)
importFrom(methods,setMethod)
importFrom(methods,show)
importFrom(methods,validObject)
importFrom(splines2,bSpline)
importFrom(splines2,iSpline)
importFrom(splines2,ibs)
importFrom(splines2,mSpline)
importFrom(stats,.getXlevels)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,constrOptim)
importFrom(stats,deriv)
importFrom(stats,integrate)
importFrom(stats,median)
importFrom(stats,model.extract)
importFrom(stats,na.exclude)
importFrom(stats,na.fail)
importFrom(stats,na.omit)
importFrom(stats,na.pass)
importFrom(stats,optimize)
importFrom(stats,pchisq)
importFrom(stats,predict)
importFrom(stats,printCoefmat)
importFrom(stats,qexp)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rexp)
importFrom(stats,rgamma)
importFrom(stats,rpois)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,stepfun)
importFrom(stats,uniroot)
useDynLib(reda)
